@@ -46,6 +46,7 @@
 #include "clutter-fixed.h"
 #include "clutter-marshal.h"
 #include "clutter-private.h"
+#include "clutter-profile.h"
 
 #include <cogl/cogl.h>
 
@@ -284,10 +285,12 @@ _clutter_backend_create_stage (ClutterBackend  *backend,
   stage_manager = clutter_stage_manager_get_default ();
 
   klass = CLUTTER_BACKEND_GET_CLASS (backend);
-  if (klass->create_stage)
+  if (klass->create_stage != NULL)
     stage_window = klass->create_stage (backend, wrapper, error);
+  else
+    stage_window = NULL;
 
-  if (!stage_window)
+  if (stage_window == NULL)
     return NULL;
 
   g_assert (CLUTTER_IS_STAGE_WINDOW (stage_window));
@@ -302,10 +305,24 @@ _clutter_backend_redraw (ClutterBackend *backend,
                          ClutterStage   *stage)
 {
   ClutterBackendClass *klass;
+  CLUTTER_STATIC_COUNTER (redraw_counter,
+                          "_clutter_backend_redraw counter",
+                          "Increments for each _clutter_backend_redraw call",
+                          0 /* no application private data */);
+  CLUTTER_STATIC_TIMER (redraw_timer,
+                        "Master Clock", /* parent */
+                        "Redrawing",
+                        "The time spent redrawing everything",
+                        0 /* no application private data */);
+
+  CLUTTER_COUNTER_INC (_clutter_uprof_context, redraw_counter);
+  CLUTTER_TIMER_START (_clutter_uprof_context, redraw_timer);
 
   klass = CLUTTER_BACKEND_GET_CLASS (backend);
   if (G_LIKELY (klass->redraw))
     klass->redraw (backend, stage);
+
+  CLUTTER_TIMER_STOP (_clutter_uprof_context, redraw_timer);
 }
 
 gboolean
@@ -410,6 +427,14 @@ _clutter_backend_get_features (ClutterBackend *backend)
   g_return_val_if_fail (CLUTTER_IS_BACKEND (backend), 0);
 
   klass = CLUTTER_BACKEND_GET_CLASS (backend);
+
+  /* we need to have a context here; so we create the
+   * GL context first and the ask for features. if the
+   * context already exists this should be a no-op
+   */
+  if (klass->create_context)
+    klass->create_context (backend, NULL);
+
   if (klass->get_features)
     return klass->get_features (backend);
   
