@@ -236,6 +236,8 @@ clutter_flow_layout_get_preferred_width (ClutterLayoutManager *manager,
   if (children)
     line_count = 1;
 
+  max_min_width = max_natural_width = 0;
+
   for (l = children; l != NULL; l = l->next)
     {
       ClutterActor *child = l->data;
@@ -385,6 +387,8 @@ clutter_flow_layout_get_preferred_height (ClutterLayoutManager *manager,
   if (children)
     line_count = 1;
 
+  max_min_height = max_natural_height = 0;
+
   for (l = children; l != NULL; l = l->next)
     {
       ClutterActor *child = l->data;
@@ -523,6 +527,8 @@ clutter_flow_layout_allocate (ClutterLayoutManager   *manager,
       if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
+      new_x = new_y = 0;
+
       if (priv->orientation == CLUTTER_FLOW_HORIZONTAL)
         {
           if (line_item_count == items_per_line && line_item_count > 0)
