@@ -180,8 +180,6 @@ struct _ClutterMainContext
   gulong redraw_count;
 
   GList *repaint_funcs;
-
-  gint internal_child;
 };
 
 #define CLUTTER_CONTEXT()	(_clutter_context_get_default ())
@@ -246,6 +244,8 @@ gboolean _clutter_stage_has_queued_events     (ClutterStage *stage);
 void     _clutter_stage_process_queued_events (ClutterStage *stage);
 void     _clutter_stage_update_input_devices  (ClutterStage *stage);
 
+int      _clutter_stage_get_pending_swaps     (ClutterStage *stage);
+
 /* vfuncs implemented by backend */
 GType         _clutter_backend_impl_get_type  (void);
 
