@@ -68,6 +68,8 @@
 #include "clutter-version.h" 	/* For flavour */
 #include "clutter-id-pool.h"
 #include "clutter-container.h"
+#include "clutter-profile.h"
+#include "clutter-input-device.h"
 
 #include "cogl/cogl.h"
 
@@ -80,6 +82,8 @@ struct _ClutterStagePrivate
 {
   /* the stage implementation */
   ClutterStageWindow *impl;
+  guint               minimum_width;
+  guint               minimum_height;
 
   ClutterColor        color;
   ClutterPerspective  perspective;
@@ -112,7 +116,8 @@ enum
   PROP_USER_RESIZE,
   PROP_USE_FOG,
   PROP_FOG,
-  PROP_USE_ALPHA
+  PROP_USE_ALPHA,
+  PROP_KEY_FOCUS
 };
 
 enum
@@ -121,6 +126,7 @@ enum
   UNFULLSCREEN,
   ACTIVATE,
   DEACTIVATE,
+  DELETE_EVENT,
 
   LAST_SIGNAL
 };
@@ -176,6 +182,7 @@ clutter_stage_allocate (ClutterActor           *self,
                         ClutterAllocationFlags  flags)
 {
   ClutterStagePrivate *priv = CLUTTER_STAGE (self)->priv;
+  ClutterGeometry geom = { 0, };
   gboolean origin_changed;
   gint width, height;
 
@@ -186,6 +193,11 @@ clutter_stage_allocate (ClutterActor           *self,
 
   width = clutter_actor_box_get_width (box);
   height = clutter_actor_box_get_height (box);
+  _clutter_stage_window_get_geometry (priv->impl, &geom);
+
+  /* XXX: Until Cogl becomes fully responsible for backend windows Clutter
+   * need to manually keep it informed of the current window size */
+  _cogl_onscreen_clutter_backend_set_size (geom.width, geom.height);
 
   /* if the stage is fixed size (for instance, it's using a frame-buffer)
    * then we simply ignore any allocation request and override the
@@ -195,10 +207,6 @@ clutter_stage_allocate (ClutterActor           *self,
     {
       ClutterActorClass *klass;
 
-      /* XXX: Until Cogl becomes fully responsible for backend windows Clutter
-       * need to manually keep it informed of the current window size */
-      _cogl_onscreen_clutter_backend_set_size (width, height);
-
       CLUTTER_NOTE (LAYOUT,
                     "Following allocation to %dx%d (origin %s)",
                     width, height,
@@ -207,20 +215,15 @@ clutter_stage_allocate (ClutterActor           *self,
       klass = CLUTTER_ACTOR_CLASS (clutter_stage_parent_class);
       klass->allocate (self, box, flags);
 
-      _clutter_stage_window_resize (priv->impl, width, height);
+      /* Ensure the window is sized correctly */
+      if ((geom.width != width) || (geom.height != height))
+        _clutter_stage_window_resize (priv->impl, width, height);
     }
   else
     {
       ClutterActorBox override = { 0, };
-      ClutterGeometry geom = { 0, };
       ClutterActorClass *klass;
 
-      _clutter_stage_window_get_geometry (priv->impl, &geom);
-
-      /* XXX: Until Cogl becomes fully responsible for backend windows Clutter
-       * need to manually keep it informed of the current window size */
-      _cogl_onscreen_clutter_backend_set_size (geom.width, geom.height);
-
       override.x1 = 0;
       override.y1 = 0;
       override.x2 = geom.width;
@@ -246,6 +249,11 @@ clutter_stage_paint (ClutterActor *self)
   ClutterStagePrivate *priv = CLUTTER_STAGE (self)->priv;
   CoglColor stage_color;
   guint8 real_alpha;
+  CLUTTER_STATIC_TIMER (stage_clear_timer,
+                        "Painting actors", /* parent */
+                        "Stage clear",
+                        "The time spent clearing the stage",
+                        0 /* no application private data */);
 
   CLUTTER_NOTE (PAINT, "Initializing stage paint");
 
@@ -264,9 +272,12 @@ clutter_stage_paint (ClutterActor *self)
                            priv->use_alpha ? real_alpha
                                            : 255);
   cogl_color_premultiply (&stage_color);
+
+  CLUTTER_TIMER_START (_clutter_uprof_context, stage_clear_timer);
   cogl_clear (&stage_color,
 	      COGL_BUFFER_BIT_COLOR |
 	      COGL_BUFFER_BIT_DEPTH);
+  CLUTTER_TIMER_STOP (_clutter_uprof_context, stage_clear_timer);
 
   if (priv->use_fog)
     {
@@ -320,8 +331,8 @@ clutter_stage_realize (ClutterActor *self)
    */
   if (is_realized)
     {
-      GError *error = NULL;
       ClutterBackend *backend = clutter_get_default_backend ();
+      GError *error = NULL;
 
       /* We want to select the context without calling
          clutter_backend_ensure_context so that it doesn't call any
@@ -333,8 +344,8 @@ clutter_stage_realize (ClutterActor *self)
       /* Make sure Cogl can support the driver */
       if (!_cogl_check_driver_valid (&error))
         {
-          g_warning ("The GL driver is not supported: %s",
-                     error->message);
+          g_critical ("The GL driver is not supported: %s",
+                      error->message);
           g_clear_error (&error);
           CLUTTER_ACTOR_UNSET_FLAGS (self, CLUTTER_ACTOR_REALIZED);
         }
@@ -444,6 +455,7 @@ _clutter_stage_queue_event (ClutterStage *stage,
 {
   ClutterStagePrivate *priv;
   gboolean first_event;
+  ClutterInputDevice *device;
 
   g_return_if_fail (CLUTTER_IS_STAGE (stage));
 
@@ -451,14 +463,31 @@ _clutter_stage_queue_event (ClutterStage *stage,
 
   first_event = priv->event_queue->length == 0;
 
-  g_queue_push_tail (priv->event_queue,
-		     clutter_event_copy (event));
+  g_queue_push_tail (priv->event_queue, clutter_event_copy (event));
 
   if (first_event)
     {
       ClutterMasterClock *master_clock = _clutter_master_clock_get_default ();
       _clutter_master_clock_start_running (master_clock);
     }
+
+  /* if needed, update the state of the input device of the event.
+   * we do it here to avoid calling the same code from every backend
+   * event processing function
+   */
+  device = clutter_event_get_device (event);
+  if (device != NULL)
+    {
+      ClutterModifierType event_state = clutter_event_get_state (event);
+      guint32 event_time = clutter_event_get_time (event);
+      gfloat event_x, event_y;
+
+      clutter_event_get_coords (event, &event_x, &event_y);
+
+      _clutter_input_device_set_coords (device, event_x, event_y);
+      _clutter_input_device_set_state (device, event_state);
+      _clutter_input_device_set_time (device, event_time);
+    }
 }
 
 gboolean
@@ -477,7 +506,7 @@ void
 _clutter_stage_process_queued_events (ClutterStage *stage)
 {
   ClutterStagePrivate *priv;
-  GList *events, *l;;
+  GList *events, *l;
 
   g_return_if_fail (CLUTTER_IS_STAGE (stage));
 
@@ -496,7 +525,7 @@ _clutter_stage_process_queued_events (ClutterStage *stage)
   priv->event_queue->tail = NULL;
   priv->event_queue->length = 0;
 
-  for (l = events; l; l = l->next)
+  for (l = events; l != NULL; l = l->next)
     {
       ClutterEvent *event;
       ClutterEvent *next_event;
@@ -616,19 +645,25 @@ clutter_stage_real_queue_redraw (ClutterActor *actor,
     CLUTTER_CONTEXT ()->redraw_count += 1;
 }
 
+static gboolean
+clutter_stage_real_delete_event (ClutterStage *stage,
+                                 ClutterEvent *event)
+{
+  if (clutter_stage_is_default (stage))
+    clutter_main_quit ();
+  else
+    clutter_actor_destroy (CLUTTER_ACTOR (stage));
+
+  return TRUE;
+}
+
 static void
 clutter_stage_set_property (GObject      *object,
 			    guint         prop_id,
 			    const GValue *value,
 			    GParamSpec   *pspec)
 {
-  ClutterStage        *stage;
-  ClutterStagePrivate *priv;
-  ClutterActor        *actor;
-
-  stage = CLUTTER_STAGE (object);
-  actor = CLUTTER_ACTOR (stage);
-  priv = stage->priv;
+  ClutterStage *stage = CLUTTER_STAGE (object);
 
   switch (prop_id)
     {
@@ -672,6 +707,10 @@ clutter_stage_set_property (GObject      *object,
       clutter_stage_set_use_alpha (stage, g_value_get_boolean (value));
       break;
 
+    case PROP_KEY_FOCUS:
+      clutter_stage_set_key_focus (stage, g_value_get_object (value));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -728,6 +767,10 @@ clutter_stage_get_property (GObject    *gobject,
       g_value_set_boolean (value, priv->use_alpha);
       break;
 
+    case PROP_KEY_FOCUS:
+      g_value_set_object (value, priv->key_focused_actor);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -788,7 +831,6 @@ clutter_stage_finalize (GObject *object)
   G_OBJECT_CLASS (clutter_stage_parent_class)->finalize (object);
 }
 
-
 static void
 clutter_stage_class_init (ClutterStageClass *klass)
 {
@@ -973,6 +1015,23 @@ clutter_stage_class_init (ClutterStageClass *klass)
                                 CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_USE_ALPHA, pspec);
 
+  /**
+   * ClutterStage:key-focus:
+   *
+   * The #ClutterActor that will receive key events from the underlying
+   * windowing system.
+   *
+   * If %NULL, the #ClutterStage will receive the events.
+   *
+   * Since: 1.2
+   */
+  pspec = g_param_spec_object ("key-focus",
+                               "Key Focus",
+                               "The currently key focused actor",
+                               CLUTTER_TYPE_ACTOR,
+                               CLUTTER_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, PROP_KEY_FOCUS, pspec);
+
   /**
    * ClutterStage::fullscreen
    * @stage: the stage which was fullscreened
@@ -1041,9 +1100,41 @@ clutter_stage_class_init (ClutterStageClass *klass)
 		  clutter_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
 
+  /**
+   * ClutterStage::delete-event:
+   * @stage: the stage that received the event
+   * @event: a #ClutterEvent of type %CLUTTER_DELETE
+   *
+   * The ::delete-event signal is emitted when the user closes a
+   * #ClutterStage window using the window controls.
+   *
+   * Clutter by default will call clutter_main_quit() if @stage is
+   * the default stage, and clutter_actor_destroy() for any other
+   * stage.
+   *
+   * It is possible to override the default behaviour by connecting
+   * a new handler and returning %TRUE there.
+   *
+   * <note>This signal is emitted only on Clutter backends that
+   * embed #ClutterStage in native windows. It is not emitted for
+   * backends that use a static frame buffer.</note>
+   *
+   * Since: 1.2
+   */
+  stage_signals[DELETE_EVENT] =
+    g_signal_new (I_("delete-event"),
+                  G_TYPE_FROM_CLASS (gobject_class),
+                  G_SIGNAL_RUN_LAST,
+                  G_STRUCT_OFFSET (ClutterStageClass, delete_event),
+                  _clutter_boolean_handled_accumulator, NULL,
+                  clutter_marshal_BOOLEAN__BOXED,
+                  G_TYPE_BOOLEAN, 1,
+                  CLUTTER_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
+
   klass->fullscreen = clutter_stage_real_fullscreen;
   klass->activate = clutter_stage_real_activate;
   klass->deactivate = clutter_stage_real_deactivate;
+  klass->delete_event = clutter_stage_real_delete_event;
 
   g_type_class_add_private (gobject_class, sizeof (ClutterStagePrivate));
 }
@@ -1081,6 +1172,8 @@ clutter_stage_init (ClutterStage *self)
   priv->throttle_motion_events = TRUE;
 
   priv->color = default_stage_color;
+  priv->minimum_width = 1;
+  priv->minimum_height = 1;
 
   priv->perspective.fovy   = 60.0; /* 60 Degrees */
   priv->perspective.aspect = 1.0;
@@ -1092,6 +1185,7 @@ clutter_stage_init (ClutterStage *self)
   priv->fog.z_far  = 2.0;
 
   clutter_actor_set_reactive (CLUTTER_ACTOR (self), TRUE);
+  clutter_stage_set_title (self, g_get_prgname ());
   clutter_stage_set_key_focus (self, NULL);
 }
 
@@ -1116,11 +1210,16 @@ clutter_stage_get_default (void)
 
   stage = clutter_stage_manager_get_default_stage (stage_manager);
   if (G_UNLIKELY (stage == NULL))
-    /* This will take care of automatically adding the stage to the
-     * stage manager and setting it as the default. Its floating
-     * reference will be claimed by the stage manager.
-     */
-    stage = g_object_new (CLUTTER_TYPE_STAGE, NULL);
+    {
+      /* This will take care of automatically adding the stage to the
+       * stage manager and setting it as the default. Its floating
+       * reference will be claimed by the stage manager.
+       */
+      stage = g_object_new (CLUTTER_TYPE_STAGE, NULL);
+
+      /* the default stage is realized by default */
+      clutter_actor_realize (CLUTTER_ACTOR (stage));
+    }
 
   return CLUTTER_ACTOR (stage);
 }
@@ -1145,8 +1244,7 @@ clutter_stage_set_color (ClutterStage       *stage,
 
   priv->color = *color;
 
-  if (CLUTTER_ACTOR_IS_VISIBLE (stage))
-    clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
+  clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
 
   g_object_notify (G_OBJECT (stage), "color");
 }
@@ -1522,6 +1620,9 @@ clutter_stage_event (ClutterStage *stage,
 
       g_signal_emit_by_name (stage, "event", event, &retval);
 
+      if (!retval)
+        g_signal_emit_by_name (stage, "delete-event", event, &retval);
+
       return retval;
     }
 
@@ -1693,6 +1794,8 @@ clutter_stage_set_key_focus (ClutterStage *stage,
     }
   else
     g_signal_emit_by_name (stage, "key-focus-in");
+
+  g_object_notify (G_OBJECT (stage), "key-focus");
 }
 
 /**
@@ -1767,8 +1870,7 @@ clutter_stage_set_use_fog (ClutterStage *stage,
       CLUTTER_NOTE (MISC, "%s depth-cueing inside stage",
                     priv->use_fog ? "enabling" : "disabling");
 
-      if (CLUTTER_ACTOR_IS_VISIBLE (stage))
-        clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
+      clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
 
       g_object_notify (G_OBJECT (stage), "use-fog");
     }
@@ -1845,7 +1947,7 @@ clutter_stage_set_fog (ClutterStage *stage,
 
   priv->fog = *fog;
 
-  if (priv->use_fog && CLUTTER_ACTOR_IS_VISIBLE (stage))
+  if (priv->use_fog)
     clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
 }
 
@@ -2213,3 +2315,87 @@ clutter_stage_get_use_alpha (ClutterStage *stage)
 
   return stage->priv->use_alpha;
 }
+
+/**
+ * clutter_stage_set_minimum_size:
+ * @stage: a #ClutterStage
+ * @width: width, in pixels
+ * @height: height, in pixels
+ *
+ * Sets the minimum size for a stage window. This has no effect if the stage
+ * is fullscreen.
+ *
+ * Since: 1.2
+ */
+void
+clutter_stage_set_minimum_size (ClutterStage *stage,
+                                guint         width,
+                                guint         height)
+{
+  ClutterGeometry geom;
+
+  g_return_if_fail (CLUTTER_IS_STAGE (stage));
+  g_return_if_fail ((width > 0) && (height > 0));
+
+  stage->priv->minimum_width = width;
+  stage->priv->minimum_height = height;
+
+  if (stage->priv->impl == NULL)
+    return;
+
+  _clutter_stage_window_get_geometry (stage->priv->impl, &geom);
+
+  if (geom.width > width)
+    width = geom.width;
+
+  if (geom.height > height)
+    height = geom.height;
+
+  /* Call resize to ensure that the minimum size is enforced by
+   * the backend.
+   */
+  if (CLUTTER_ACTOR_IS_MAPPED (stage))
+    _clutter_stage_window_resize (stage->priv->impl, width, height);
+}
+
+/**
+ * clutter_stage_get_minimum_size:
+ * @stage: a #ClutterStage
+ * @width: width, in pixels
+ * @height: height, in pixels
+ *
+ * Gets the set minimum size for a stage window. This may not correspond
+ * to the actual minimum size and is specific to the back-end
+ * implementation.
+ *
+ * Since: 1.2
+ */
+void
+clutter_stage_get_minimum_size (ClutterStage *stage,
+                                guint        *width,
+                                guint        *height)
+{
+  g_return_if_fail (CLUTTER_IS_STAGE (stage));
+
+  if (width)
+    *width = stage->priv->minimum_width;
+  if (height)
+    *height = stage->priv->minimum_height;
+}
+
+/* Returns the number of swap buffers pending completion for the stage */
+int
+_clutter_stage_get_pending_swaps (ClutterStage *stage)
+{
+  ClutterStageWindow *stage_window;
+
+  if (CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_ACTOR_IN_DESTRUCTION)
+    return 0;
+
+  stage_window = _clutter_stage_get_window (stage);
+  if (stage_window == NULL)
+    return 0;
+
+  return _clutter_stage_window_get_pending_swaps (stage_window);
+}
+
