@@ -34,6 +34,10 @@
 #ifndef __CLUTTER_VERSION_H__
 #define __CLUTTER_VERSION_H__
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 /**
  * CLUTTER_MAJOR_VERSION:
  *
@@ -53,14 +57,14 @@
  *
  * The micro version of the Clutter library (3, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MICRO_VERSION   (2)
+#define CLUTTER_MICRO_VERSION   (12)
 
 /**
  * CLUTTER_VERSION:
  *
  * The full version of the Clutter library, like 1.2.3
  */
-#define CLUTTER_VERSION         1.1.2
+#define CLUTTER_VERSION         1.1.12
 
 /**
  * CLUTTER_VERSION_S:
@@ -68,7 +72,7 @@
  * The full version of the Clutter library, in string form (suited for
  * string concatenation)
  */
-#define CLUTTER_VERSION_S       "1.1.2"
+#define CLUTTER_VERSION_S       "1.1.12"
 
 /**
  * CLUTTER_VERSION_HEX:
@@ -117,7 +121,7 @@
  *
  * The default GObject type for the Clutter stage. 
  *
- * Since 0.8
+ * Since: 0.8
  */
 #define CLUTTER_STAGE_TYPE CLUTTER_TYPE_STAGE_GLX
 
@@ -131,5 +135,14 @@
  */
 #define CLUTTER_NO_FPU          CLUTTER_NO_FPU_MACRO_WAS_REMOVED
 
+extern const guint clutter_major_version;
+extern const guint clutter_minor_version;
+extern const guint clutter_micro_version;
+
+gboolean clutter_check_version (guint major,
+                                guint minor,
+                                guint micro);
+
+G_END_DECLS
 
 #endif /* __CLUTTER_VERSION_H__ */
