@@ -30,6 +30,8 @@
 #include "cogl-clip-stack.h"
 #include "cogl-matrix-stack.h"
 #include "cogl-material-private.h"
+#include "cogl-atlas.h"
+#include "cogl-buffer-private.h"
 
 typedef struct
 {
@@ -47,7 +49,7 @@ typedef struct
   CoglHandle        default_material;
 
   /* Enable cache */
-  gulong            enable_flags;
+  unsigned long     enable_flags;
   guint8            color_alpha;
 
   gboolean          enable_backface_culling;
@@ -81,10 +83,14 @@ typedef struct
 
   /* Some simple caching, to minimize state changes... */
   CoglHandle	    current_material;
-  gulong            current_material_flags;
+  unsigned long     current_material_flags;
   CoglMaterialFlushOptions current_material_flush_options;
   GArray           *current_layers;
-  guint             n_texcoord_arrays_enabled;
+  unsigned int      n_texcoord_arrays_enabled;
+
+  /* PBOs */
+  /* This can be used to check if a pbo is bound */
+  CoglBuffer       *current_pbo;
 
   /* Framebuffers */
   GSList           *framebuffer_stack;
@@ -96,7 +102,7 @@ typedef struct
   floatVec2         path_start;
   floatVec2         path_pen;
   GArray           *path_nodes;
-  guint             last_path;
+  unsigned int      last_path;
   floatVec2         path_nodes_min;
   floatVec2         path_nodes_max;
   CoglHandle        stencil_material;
@@ -104,13 +110,26 @@ typedef struct
   /* Pre-generated VBOs containing indices to generate GL_TRIANGLES
      out of a vertex array of quads */
   CoglHandle        quad_indices_byte;
-  guint             quad_indices_short_len;
+  unsigned int      quad_indices_short_len;
   CoglHandle        quad_indices_short;
 
   gboolean          in_begin_gl_block;
 
   CoglHandle        texture_download_material;
 
+  CoglAtlas        *atlas;
+  CoglHandle        atlas_texture;
+
+  /* This debugging variable is used to pick a colour for visually
+     displaying the quad batches. It needs to be global so that it can
+     be reset by cogl_clear. It needs to be reset to increase the
+     chances of getting the same colour during an animation */
+  guint8            journal_rectangles_color;
+
+  /* Cached value for GL_MAX_TEXTURE_UNITS to avoid calling
+     glGetInteger too often */
+  GLint             max_texture_units;
+
   CoglContextDriver drv;
 } CoglContext;
 
