@@ -4,6 +4,78 @@
 #include "cogl-enum-types.h"
 #include "cogl.h"
 
+/* enumerations from "./cogl-buffer.h" */
+#include "./cogl-buffer.h"
+
+GType
+cogl_buffer_usage_hint_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_BUFFER_USAGE_HINT_TEXTURE, "COGL_BUFFER_USAGE_HINT_TEXTURE", "texture" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglBufferUsageHint"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+GType
+cogl_buffer_update_hint_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_BUFFER_UPDATE_HINT_STATIC, "COGL_BUFFER_UPDATE_HINT_STATIC", "static" },
+        { COGL_BUFFER_UPDATE_HINT_DYNAMIC, "COGL_BUFFER_UPDATE_HINT_DYNAMIC", "dynamic" },
+        { COGL_BUFFER_UPDATE_HINT_STREAM, "COGL_BUFFER_UPDATE_HINT_STREAM", "stream" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglBufferUpdateHint"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+GType
+cogl_buffer_access_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GFlagsValue values[] = {
+        { COGL_BUFFER_ACCESS_READ, "COGL_BUFFER_ACCESS_READ", "read" },
+        { COGL_BUFFER_ACCESS_WRITE, "COGL_BUFFER_ACCESS_WRITE", "write" },
+        { COGL_BUFFER_ACCESS_READ_WRITE, "COGL_BUFFER_ACCESS_READ_WRITE", "read-write" },
+        { COGL_BUFFER_ACCESS_WRITE, "COGL_BUFFER_ACCESS_WRITE", "write" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_flags_register_static (g_intern_static_string ("CoglBufferAccess"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
 /* enumerations from "./cogl-debug.h" */
 #include "./cogl-debug.h"
 
@@ -26,11 +98,15 @@ cogl_debug_flags_get_type (void)
         { COGL_DEBUG_HANDLE, "COGL_DEBUG_HANDLE", "handle" },
         { COGL_DEBUG_BLEND_STRINGS, "COGL_DEBUG_BLEND_STRINGS", "blend-strings" },
         { COGL_DEBUG_DISABLE_BATCHING, "COGL_DEBUG_DISABLE_BATCHING", "disable-batching" },
-        { COGL_DEBUG_FORCE_CLIENT_SIDE_MATRICES, "COGL_DEBUG_FORCE_CLIENT_SIDE_MATRICES", "force-client-side-matrices" },
         { COGL_DEBUG_DISABLE_VBOS, "COGL_DEBUG_DISABLE_VBOS", "disable-vbos" },
         { COGL_DEBUG_JOURNAL, "COGL_DEBUG_JOURNAL", "journal" },
         { COGL_DEBUG_BATCHING, "COGL_DEBUG_BATCHING", "batching" },
         { COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM, "COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM", "disable-software-transform" },
+        { COGL_DEBUG_MATRICES, "COGL_DEBUG_MATRICES", "matrices" },
+        { COGL_DEBUG_FORCE_SCANLINE_PATHS, "COGL_DEBUG_FORCE_SCANLINE_PATHS", "force-scanline-paths" },
+        { COGL_DEBUG_ATLAS, "COGL_DEBUG_ATLAS", "atlas" },
+        { COGL_DEBUG_DUMP_ATLAS_IMAGE, "COGL_DEBUG_DUMP_ATLAS_IMAGE", "dump-atlas-image" },
+        { COGL_DEBUG_DISABLE_ATLAS, "COGL_DEBUG_DISABLE_ATLAS", "disable-atlas" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -210,6 +286,7 @@ cogl_feature_flags_get_type (void)
         { COGL_FEATURE_FOUR_CLIP_PLANES, "COGL_FEATURE_FOUR_CLIP_PLANES", "four-clip-planes" },
         { COGL_FEATURE_STENCIL_BUFFER, "COGL_FEATURE_STENCIL_BUFFER", "stencil-buffer" },
         { COGL_FEATURE_VBOS, "COGL_FEATURE_VBOS", "vbos" },
+        { COGL_FEATURE_PBOS, "COGL_FEATURE_PBOS", "pbos" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -255,6 +332,7 @@ cogl_texture_flags_get_type (void)
         { COGL_TEXTURE_NONE, "COGL_TEXTURE_NONE", "none" },
         { COGL_TEXTURE_NO_AUTO_MIPMAP, "COGL_TEXTURE_NO_AUTO_MIPMAP", "no-auto-mipmap" },
         { COGL_TEXTURE_NO_SLICING, "COGL_TEXTURE_NO_SLICING", "no-slicing" },
+        { COGL_TEXTURE_NO_ATLAS, "COGL_TEXTURE_NO_ATLAS", "no-atlas" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -393,8 +471,8 @@ cogl_indices_type_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "../../../clutter/cogl/cogl/cogl.h" */
-#include "../../../clutter/cogl/cogl/cogl.h"
+/* enumerations from "./cogl.h" */
+#include "./cogl.h"
 
 GType
 cogl_buffer_bit_get_type (void)
@@ -440,6 +518,28 @@ cogl_read_pixels_flags_get_type (void)
 
   return g_enum_type_id__volatile;
 }
+GType
+cogl_driver_error_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_DRIVER_ERROR_UNKNOWN_VERSION, "COGL_DRIVER_ERROR_UNKNOWN_VERSION", "unknown-version" },
+        { COGL_DRIVER_ERROR_INVALID_VERSION, "COGL_DRIVER_ERROR_INVALID_VERSION", "invalid-version" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglDriverError"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
 
 /* Generated data ends here */
 
