@@ -33,6 +33,7 @@
 #include "cogl-material-private.h"
 #include "cogl-vertex-buffer-private.h"
 #include "cogl-framebuffer-private.h"
+#include "cogl-profile.h"
 
 #include <string.h>
 #include <gmodule.h>
@@ -87,7 +88,7 @@ typedef CoglVertexBufferIndices  CoglJournalIndices;
 
 typedef struct _CoglJournalFlushState
 {
-  size_t              stride;
+  gsize              stride;
   /* Note: this is a pointer to handle fallbacks. It normally holds a VBO
    * offset, but when the driver doesn't support VBOs then this points into
    * our GArray of logged vertices. */
@@ -95,7 +96,7 @@ typedef struct _CoglJournalFlushState
   GLuint              vertex_offset;
 #ifndef HAVE_COGL_GL
   CoglJournalIndices *indices;
-  size_t              indices_type_size;
+  gsize              indices_type_size;
 #endif
   CoglMatrixStack    *modelview_stack;
 } CoglJournalFlushState;
@@ -109,7 +110,7 @@ typedef gboolean (*CoglJournalBatchTest) (CoglJournalEntry *entry0,
 void
 _cogl_journal_dump_quad_vertices (guint8 *data, int n_layers)
 {
-  size_t stride = GET_JOURNAL_VB_STRIDE_FOR_N_LAYERS (n_layers);
+  gsize stride = GET_JOURNAL_VB_STRIDE_FOR_N_LAYERS (n_layers);
   int i;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
@@ -143,7 +144,7 @@ _cogl_journal_dump_quad_vertices (guint8 *data, int n_layers)
 void
 _cogl_journal_dump_quad_batch (guint8 *data, int n_layers, int n_quads)
 {
-  size_t byte_stride = GET_JOURNAL_VB_STRIDE_FOR_N_LAYERS (n_layers) * 4;
+  gsize byte_stride = GET_JOURNAL_VB_STRIDE_FOR_N_LAYERS (n_layers) * 4;
   int i;
 
   g_print ("_cogl_journal_dump_quad_batch: n_layers = %d, n_quads = %d\n",
@@ -163,6 +164,9 @@ batch_and_call (CoglJournalEntry *entries,
   int batch_len = 1;
   CoglJournalEntry *batch_start = entries;
 
+  if (n_entries < 1)
+    return;
+
   for (i = 1; i < n_entries; i++)
     {
       CoglJournalEntry *entry0 = &entries[i - 1];
@@ -224,30 +228,51 @@ _cogl_journal_flush_modelview_and_entries (CoglJournalEntry *batch_start,
     }
 #endif
 
-  /* DEBUGGING CODE XXX:
-   * This path will cause all rectangles to be drawn with a red, green
-   * or blue outline with no blending. This may e.g. help with debugging
-   * texture slicing issues or blending issues, plus it looks quite cool.
+  /* DEBUGGING CODE XXX: This path will cause all rectangles to be
+   * drawn with a coloured outline. Each batch will be rendered with
+   * the same color. This may e.g. help with debugging texture slicing
+   * issues, visually seeing what is batched and debugging blending
+   * issues, plus it looks quite cool.
    */
   if (cogl_debug_flags & COGL_DEBUG_RECTANGLES)
     {
       static CoglHandle outline = COGL_INVALID_HANDLE;
-      static int color = 0;
+      guint8 color_intensity;
       int i;
+
+      _COGL_GET_CONTEXT (ctxt, NO_RETVAL);
+
       if (outline == COGL_INVALID_HANDLE)
         outline = cogl_material_new ();
 
+      /* The least significant three bits represent the three
+         components so that the order of colours goes red, green,
+         yellow, blue, magenta, cyan. Black and white are skipped. The
+         next two bits give four scales of intensity for those colours
+         in the order 0xff, 0xcc, 0x99, and 0x66. This gives a total
+         of 24 colours. If there are more than 24 batches on the stage
+         then it will wrap around */
+      color_intensity = 0xff - 0x33 * (ctxt->journal_rectangles_color >> 3);
+      cogl_material_set_color4ub (outline,
+                                  (ctxt->journal_rectangles_color & 1) ?
+                                  color_intensity : 0,
+                                  (ctxt->journal_rectangles_color & 2) ?
+                                  color_intensity : 0,
+                                  (ctxt->journal_rectangles_color & 4) ?
+                                  color_intensity : 0,
+                                  0xff);
+      _cogl_material_flush_gl_state (outline, NULL);
       cogl_enable (COGL_ENABLE_VERTEX_ARRAY);
-      for (i = 0; i < batch_len; i++, color = (color + 1) % 3)
-        {
-          cogl_material_set_color4ub (outline,
-                                      color == 0 ? 0xff : 0x00,
-                                      color == 1 ? 0xff : 0x00,
-                                      color == 2 ? 0xff : 0x00,
-                                      0xff);
-          _cogl_material_flush_gl_state (outline, NULL);
-          GE( glDrawArrays (GL_LINE_LOOP, 4 * i, 4) );
-        }
+      for (i = 0; i < batch_len; i++)
+        GE( glDrawArrays (GL_LINE_LOOP, 4 * i + state->vertex_offset, 4) );
+
+      /* Go to the next color */
+      do
+        ctxt->journal_rectangles_color = ((ctxt->journal_rectangles_color + 1) &
+                                          ((1 << 5) - 1));
+      /* We don't want to use black or white */
+      while ((ctxt->journal_rectangles_color & 0x07) == 0
+             || (ctxt->journal_rectangles_color & 0x07) == 0x07);
     }
 
   state->vertex_offset += (4 * batch_len);
@@ -279,10 +304,10 @@ compare_entry_modelviews (CoglJournalEntry *entry0,
  * materials, but they may not all have the same modelview matrix */
 static void
 _cogl_journal_flush_material_and_entries (CoglJournalEntry *batch_start,
-                                          gint              batch_len,
+                                          int               batch_len,
                                           void             *data)
 {
-  gulong                 enable_flags = 0;
+  unsigned long enable_flags = 0;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
@@ -342,7 +367,7 @@ compare_entry_materials (CoglJournalEntry *entry0, CoglJournalEntry *entry1)
 static void
 _cogl_journal_flush_texcoord_vbo_offsets_and_entries (
                                           CoglJournalEntry *batch_start,
-                                          gint              batch_len,
+                                          int               batch_len,
                                           void             *data)
 {
   CoglJournalFlushState *state = data;
@@ -398,11 +423,11 @@ compare_entry_n_layers (CoglJournalEntry *entry0, CoglJournalEntry *entry1)
  * of journal entries */
 static void
 _cogl_journal_flush_vbo_offsets_and_entries (CoglJournalEntry *batch_start,
-                                             gint              batch_len,
+                                             int               batch_len,
                                              void             *data)
 {
   CoglJournalFlushState   *state = data;
-  size_t                   stride;
+  gsize                   stride;
 #ifndef HAVE_COGL_GL
   int                      needed_indices = batch_len * 6;
   CoglHandle               indices_handle;
@@ -477,7 +502,7 @@ _cogl_journal_flush_vbo_offsets_and_entries (CoglJournalEntry *batch_start,
   /* progress forward through the VBO containing all our vertices */
   state->vbo_offset += (stride * 4 * batch_len);
   if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_JOURNAL))
-    g_print ("new vbo offset = %lu\n", (gulong)state->vbo_offset);
+    g_print ("new vbo offset = %lu\n", (unsigned long)state->vbo_offset);
 }
 
 static gboolean
@@ -499,7 +524,7 @@ compare_entry_strides (CoglJournalEntry *entry0, CoglJournalEntry *entry1)
 static GLuint
 upload_vertices_to_vbo (GArray *vertices, CoglJournalFlushState *state)
 {
-  size_t needed_vbo_len;
+  gsize needed_vbo_len;
   GLuint journal_vbo;
 
   _COGL_GET_CONTEXT (ctx, 0);
@@ -535,12 +560,19 @@ _cogl_journal_flush (void)
     (cogl_get_features () & COGL_FEATURE_VBOS) ? FALSE : TRUE;
   CoglHandle            framebuffer;
   CoglMatrixStack      *modelview_stack;
+  COGL_STATIC_TIMER (flush_timer,
+                     "Mainloop", /* parent */
+                     "Journal Flush",
+                     "The time spent flushing the Cogl journal",
+                     0 /* no application private data */);
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
   if (ctx->journal->len == 0)
     return;
 
+  COGL_TIMER_START (_cogl_uprof_context, flush_timer);
+
   if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_BATCHING))
     g_print ("BATCHING: journal len = %d\n", ctx->journal->len);
 
@@ -608,6 +640,8 @@ _cogl_journal_flush (void)
 
   g_array_set_size (ctx->journal, 0);
   g_array_set_size (ctx->logged_vertices, 0);
+
+  COGL_TIMER_STOP (_cogl_uprof_context, flush_timer);
 }
 
 static void
@@ -623,19 +657,16 @@ _cogl_journal_init (void)
 }
 
 void
-_cogl_journal_log_quad (float         x_1,
-                        float         y_1,
-                        float         x_2,
-                        float         y_2,
+_cogl_journal_log_quad (const float  *position,
                         CoglHandle    material,
                         int           n_layers,
                         guint32       fallback_layers,
                         GLuint        layer0_override_texture,
-                        float        *tex_coords,
+                        const float  *tex_coords,
                         unsigned int  tex_coords_len)
 {
-  size_t            stride;
-  size_t            byte_stride;
+  gsize            stride;
+  gsize            byte_stride;
   int               next_vert;
   GLfloat          *v;
   GLubyte          *c;
@@ -644,9 +675,16 @@ _cogl_journal_log_quad (float         x_1,
   int               next_entry;
   guint32           disable_layers;
   CoglJournalEntry *entry;
+  COGL_STATIC_TIMER (log_timer,
+                     "Mainloop", /* parent */
+                     "Journal Log",
+                     "The time spent logging in the Cogl journal",
+                     0 /* no application private data */);
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
+  COGL_TIMER_START (_cogl_uprof_context, log_timer);
+
   if (ctx->logged_vertices->len == 0)
     _cogl_journal_init ();
 
@@ -681,15 +719,20 @@ _cogl_journal_log_quad (float         x_1,
       memcpy (c, src_c, 4);
     }
 
+#define X0 0
+#define Y0 1
+#define X1 2
+#define Y1 3
+
   if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM))
     {
-      v[0] = x_1; v[1] = y_1;
+      v[0] = position[X0]; v[1] = position[Y0];
       v += stride;
-      v[0] = x_1; v[1] = y_2;
+      v[0] = position[X0]; v[1] = position[Y1];
       v += stride;
-      v[0] = x_2; v[1] = y_2;
+      v[0] = position[X1]; v[1] = position[Y1];
       v += stride;
-      v[0] = x_2; v[1] = y_1;
+      v[0] = position[X1]; v[1] = position[Y0];
     }
   else
     {
@@ -698,23 +741,28 @@ _cogl_journal_log_quad (float         x_1,
 
       cogl_get_modelview_matrix (&mv);
 
-      x = x_1, y = y_1, z = 0; w = 1;
+      x = position[X0], y = position[Y0], z = 0; w = 1;
       cogl_matrix_transform_point (&mv, &x, &y, &z, &w);
       v[0] = x; v[1] = y; v[2] = z;
       v += stride;
-      x = x_1, y = y_2, z = 0; w = 1;
+      x = position[X0], y = position[Y1], z = 0; w = 1;
       cogl_matrix_transform_point (&mv, &x, &y, &z, &w);
       v[0] = x; v[1] = y; v[2] = z;
       v += stride;
-      x = x_2, y = y_2, z = 0; w = 1;
+      x = position[X1], y = position[Y1], z = 0; w = 1;
       cogl_matrix_transform_point (&mv, &x, &y, &z, &w);
       v[0] = x; v[1] = y; v[2] = z;
       v += stride;
-      x = x_2, y = y_1, z = 0; w = 1;
+      x = position[X1], y = position[Y0], z = 0; w = 1;
       cogl_matrix_transform_point (&mv, &x, &y, &z, &w);
       v[0] = x; v[1] = y; v[2] = z;
     }
 
+#undef X0
+#undef Y0
+#undef X1
+#undef Y1
+
   for (i = 0; i < n_layers; i++)
     {
       /* XXX: See definition of GET_JOURNAL_VB_STRIDE_FOR_N_LAYERS for details
@@ -723,13 +771,13 @@ _cogl_journal_log_quad (float         x_1,
                                    next_vert +  POS_STRIDE +
                                    COLOR_STRIDE + TEX_STRIDE * i);
 
-      t[0] = tex_coords[0]; t[1] = tex_coords[1];
+      t[0] = tex_coords[i * 4 + 0]; t[1] = tex_coords[i * 4 + 1];
       t += stride;
-      t[0] = tex_coords[0]; t[1] = tex_coords[3];
+      t[0] = tex_coords[i * 4 + 0]; t[1] = tex_coords[i * 4 + 3];
       t += stride;
-      t[0] = tex_coords[2]; t[1] = tex_coords[3];
+      t[0] = tex_coords[i * 4 + 2]; t[1] = tex_coords[i * 4 + 3];
       t += stride;
-      t[0] = tex_coords[2]; t[1] = tex_coords[1];
+      t[0] = tex_coords[i * 4 + 2]; t[1] = tex_coords[i * 4 + 1];
     }
 
   if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_JOURNAL))
@@ -762,8 +810,9 @@ _cogl_journal_log_quad (float         x_1,
   if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM))
     cogl_get_modelview_matrix (&entry->model_view);
 
-  if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_DISABLE_BATCHING
-                  || cogl_debug_flags & COGL_DEBUG_RECTANGLES))
+  if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_DISABLE_BATCHING))
     _cogl_journal_flush ();
+
+  COGL_TIMER_STOP (_cogl_uprof_context, log_timer);
 }
 
