@@ -40,6 +40,7 @@
 #include "cogl-winsys.h"
 #include "cogl-framebuffer-private.h"
 #include "cogl-matrix-private.h"
+#include "cogl-journal-private.h"
 
 #if defined (HAVE_COGL_GLES2) || defined (HAVE_COGL_GLES)
 #include "cogl-gles2-wrapper.h"
@@ -53,7 +54,7 @@
 /* GL error to string conversion */
 static const struct {
   GLuint error_code;
-  const gchar *error_string;
+  const char *error_string;
 } gl_errors[] = {
   { GL_NO_ERROR,          "No error" },
   { GL_INVALID_ENUM,      "Invalid enumeration value" },
@@ -68,12 +69,12 @@ static const struct {
 #endif
 };
 
-static const guint n_gl_errors = G_N_ELEMENTS (gl_errors);
+static const unsigned int n_gl_errors = G_N_ELEMENTS (gl_errors);
 
-const gchar *
+const char *
 cogl_gl_error_to_string (GLenum error_code)
 {
-  gint i;
+  int i;
 
   for (i = 0; i < n_gl_errors; i++)
     {
@@ -86,7 +87,7 @@ cogl_gl_error_to_string (GLenum error_code)
 #endif /* COGL_GL_DEBUG */
 
 CoglFuncPtr
-cogl_get_proc_address (const gchar* name)
+cogl_get_proc_address (const char* name)
 {
   void *address;
   static GModule *module = NULL;
@@ -111,8 +112,40 @@ cogl_get_proc_address (const gchar* name)
   return NULL;
 }
 
+gboolean
+_cogl_check_extension (const char *name, const gchar *ext)
+{
+  char *end;
+  int name_len, n;
+
+  if (name == NULL || ext == NULL)
+    return FALSE;
+
+  end = (char*)(ext + strlen(ext));
+
+  name_len = strlen(name);
+
+  while (ext < end)
+    {
+      n = strcspn(ext, " ");
+
+      if ((name_len == n) && (!strncmp(name, ext, n)))
+	return TRUE;
+      ext += (n + 1);
+    }
+
+  return FALSE;
+}
+
+/* XXX: This has been deprecated as public API */
+gboolean
+cogl_check_extension (const char *name, const char *ext)
+{
+  return _cogl_check_extension (name, ext);
+}
+
 void
-cogl_clear (const CoglColor *color, gulong buffers)
+cogl_clear (const CoglColor *color, unsigned long buffers)
 {
   GLbitfield gl_buffers = 0;
 
@@ -155,13 +188,23 @@ cogl_clear (const CoglColor *color, gulong buffers)
 
   glClear (gl_buffers);
 
+  /* This is a debugging variable used to visually display the quad
+     batches from the journal. It is reset here to increase the
+     chances of getting the same colours for each frame during an
+     animation */
+  if (G_UNLIKELY (cogl_debug_flags & COGL_DEBUG_RECTANGLES))
+    {
+      _COGL_GET_CONTEXT (ctxt, NO_RETVAL);
+      ctxt->journal_rectangles_color = 1;
+    }
+
   COGL_NOTE (DRAW, "Clear end");
 }
 
 static inline gboolean
 cogl_toggle_flag (CoglContext *ctx,
-		  gulong new_flags,
-		  gulong flag,
+		  unsigned long new_flags,
+		  unsigned long flag,
 		  GLenum gl_flag)
 {
   /* Toggles and caches a single enable flag on or off
@@ -187,8 +230,8 @@ cogl_toggle_flag (CoglContext *ctx,
 
 static inline gboolean
 cogl_toggle_client_flag (CoglContext *ctx,
-			 gulong new_flags,
-			 gulong flag,
+			 unsigned long new_flags,
+			 unsigned long flag,
 			 GLenum gl_flag)
 {
   /* Toggles and caches a single client-side enable flag
@@ -213,7 +256,7 @@ cogl_toggle_client_flag (CoglContext *ctx,
 }
 
 void
-cogl_enable (gulong flags)
+cogl_enable (unsigned long flags)
 {
   /* This function essentially caches glEnable state() in the
    * hope of lessening number GL traffic.
@@ -237,7 +280,7 @@ cogl_enable (gulong flags)
 			   GL_COLOR_ARRAY);
 }
 
-gulong
+unsigned long
 cogl_get_enable ()
 {
   _COGL_GET_CONTEXT (ctx, 0);
@@ -359,15 +402,15 @@ cogl_set_viewport (int x,
 /* XXX: This should be deprecated, and we should expose a way to also
  * specify an x and y viewport offset */
 void
-cogl_viewport (guint width,
-	       guint height)
+cogl_viewport (unsigned int width,
+	       unsigned int height)
 {
   cogl_set_viewport (0, 0, width, height);
 }
 
 void
-_cogl_setup_viewport (guint width,
-                      guint height,
+_cogl_setup_viewport (unsigned int width,
+                      unsigned int height,
                       float fovy,
                       float aspect,
                       float z_near,
@@ -482,10 +525,10 @@ cogl_get_viewport (float v[4])
 }
 
 void
-cogl_get_bitmasks (gint *red,
-                   gint *green,
-                   gint *blue,
-                   gint *alpha)
+cogl_get_bitmasks (int *red,
+                   int *green,
+                   int *blue,
+                   int *alpha)
 {
   GLint value;
 
@@ -655,7 +698,7 @@ void
 cogl_begin_gl (void)
 {
   CoglMaterialFlushOptions options;
-  gulong enable_flags = 0;
+  unsigned long enable_flags = 0;
   int i;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
@@ -729,10 +772,11 @@ cogl_end_gl (void)
 }
 
 static CoglTextureUnit *
-_cogl_texture_unit_new (void)
+_cogl_texture_unit_new (int index_)
 {
   CoglTextureUnit *unit = g_new0 (CoglTextureUnit, 1);
   unit->matrix_stack = _cogl_matrix_stack_new ();
+  unit->index = index_;
   return unit;
 }
 
@@ -766,7 +810,7 @@ _cogl_get_texture_unit (int index_)
   /* NB: if we now insert a new layer before l, that will maintain order.
    */
 
-  unit = _cogl_texture_unit_new ();
+  unit = _cogl_texture_unit_new (index_);
 
   /* Note: see comment after for() loop above */
   ctx->texture_units =
@@ -787,6 +831,42 @@ _cogl_destroy_texture_units (void)
   g_list_free (ctx->texture_units);
 }
 
+/*
+ * This is more complicated than that, another pass needs to be done when
+ * cogl have a neat way of saying if we are using the fixed function pipeline
+ * or not (for the GL case):
+ * MAX_TEXTURE_UNITS: fixed function pipeline, a texture unit has both a
+ *                    sampler and a set of texture coordinates
+ * MAX_TEXTURE_IMAGE_UNITS: number of samplers one can use from a fragment
+ *                          program/shader (ARBfp1.0 asm/GLSL)
+ * MAX_VERTEX_TEXTURE_UNITS: number of samplers one can use from a vertex
+ *                           program/shader (can be 0)
+ * MAX_COMBINED_TEXTURE_IMAGE_UNITS: Maximum samplers one can use, counting both
+ *                                   the vertex and fragment shaders
+ *
+ * If both the vertex shader and the fragment processing stage access the same
+ * texture image unit, then that counts as using two texture image units
+ * against the latter limit: http://www.opengl.org/sdk/docs/man/xhtml/glGet.xml
+ *
+ * Note that, for now, we use GL_MAX_TEXTURE_UNITS as we are exposing the
+ * fixed function pipeline.
+ */
+unsigned int
+_cogl_get_max_texture_image_units (void)
+{
+  _COGL_GET_CONTEXT (ctx, 0);
+
+  /* This function is called quite often so we cache the value to
+     avoid too many GL calls */
+  if (ctx->max_texture_units == -1)
+    {
+      ctx->max_texture_units = 1;
+      GE( glGetIntegerv (GL_MAX_TEXTURE_UNITS, &ctx->max_texture_units) );
+    }
+
+  return ctx->max_texture_units;
+}
+
 void
 cogl_push_matrix (void)
 {
