@@ -38,6 +38,7 @@
 #include <cogl/cogl-material.h>
 #include <cogl/cogl-matrix.h>
 #include <cogl/cogl-offscreen.h>
+#include <cogl/cogl-primitives.h>
 #include <cogl/cogl-path.h>
 #include <cogl/cogl-shader.h>
 #include <cogl/cogl-texture.h>
@@ -73,7 +74,8 @@ G_BEGIN_DECLS
  *
  * Since: 1.0
  */
-GOptionGroup *  cogl_get_option_group         (void);
+GOptionGroup *
+cogl_get_option_group (void);
 
 /* Misc */
 /**
@@ -85,7 +87,8 @@ GOptionGroup *  cogl_get_option_group         (void);
  *
  * Since: 0.8
  */
-CoglFeatureFlags cogl_get_features         (void);
+CoglFeatureFlags
+cogl_get_features (void);
 
 /**
  * cogl_features_available:
@@ -98,7 +101,8 @@ CoglFeatureFlags cogl_get_features         (void);
  *
  * Return value: %TRUE if the features are available, %FALSE otherwise.
  */
-gboolean        cogl_features_available       (CoglFeatureFlags    features);
+gboolean
+cogl_features_available (CoglFeatureFlags features);
 
 /**
  * cogl_get_proc_address:
@@ -111,7 +115,10 @@ gboolean        cogl_features_available       (CoglFeatureFlags    features);
  * Return value: a pointer to the requested function or %NULL if the
  *   function is not available.
  */
-CoglFuncPtr     cogl_get_proc_address         (const gchar        *name);
+CoglFuncPtr
+cogl_get_proc_address (const char *name);
+
+#ifndef COGL_DISABLE_DEPRECATED
 
 /**
  * cogl_check_extension:
@@ -121,9 +128,16 @@ CoglFuncPtr     cogl_get_proc_address         (const gchar        *name);
  * Check whether @name occurs in list of extensions in @ext.
  *
  * Return value: %TRUE if the extension occurs in the list, %FALSE otherwize.
+ *
+ * Deprecated: 1.2: OpenGL is an implementation detail for Cogl and so it's not
+ *                  appropriate to expose OpenGL extensions through the Cogl
+ *                  API.
  */
-gboolean        cogl_check_extension          (const gchar        *name,
-                                               const gchar        *ext);
+gboolean
+cogl_check_extension (const char *name,
+                      const char *ext) G_GNUC_DEPRECATED;
+
+#endif /* COGL_DISABLE_DEPRECATED */
 
 /**
  * cogl_get_bitmasks:
@@ -136,10 +150,11 @@ gboolean        cogl_check_extension          (const gchar        *name,
  * in the color buffer. Pass %NULL for any of the arguments if the
  * value is not required.
  */
-void            cogl_get_bitmasks             (gint               *red,
-                                               gint               *green,
-                                               gint               *blue,
-                                               gint               *alpha);
+void
+cogl_get_bitmasks (int *red,
+                   int *green,
+                   int *blue,
+                   int *alpha);
 
 /**
  * cogl_perspective:
@@ -151,10 +166,11 @@ void            cogl_get_bitmasks             (gint               *red,
  * Replaces the current projection matrix with a perspective matrix
  * based on the provided values.
  */
-void            cogl_perspective              (float        fovy,
-                                               float        aspect,
-                                               float        z_near,
-                                               float        z_far);
+void
+cogl_perspective (float fovy,
+                  float aspect,
+                  float z_near,
+                  float z_far);
 
 /**
  * cogl_frustum:
@@ -170,12 +186,13 @@ void            cogl_perspective              (float        fovy,
  *
  * Since: 0.8.2
  */
-void            cogl_frustum                  (float        left,
-					       float        right,
-					       float        bottom,
-					       float        top,
-                                               float        z_near,
-                                               float        z_far);
+void
+cogl_frustum (float left,
+              float right,
+              float bottom,
+              float top,
+              float z_near,
+              float z_far);
 
 /**
  * cogl_ortho:
@@ -193,12 +210,13 @@ void            cogl_frustum                  (float        left,
  *
  * Since: 1.0
  */
-void            cogl_ortho                    (float left,
-                                               float right,
-                                               float bottom,
-                                               float top,
-                                               float near,
-                                               float far);
+void
+cogl_ortho (float left,
+            float right,
+            float bottom,
+            float top,
+            float near,
+            float far);
 
 /*
  * _cogl_setup_viewport:
@@ -218,12 +236,13 @@ void            cogl_ortho                    (float left,
  *
  * This function is used only by Clutter.
  */
-void            _cogl_setup_viewport          (guint        width,
-                                               guint        height,
-                                               float        fovy,
-                                               float        aspect,
-                                               float        z_near,
-                                               float        z_far);
+void
+_cogl_setup_viewport (unsigned int width,
+                      unsigned int height,
+                      float fovy,
+                      float aspect,
+                      float z_near,
+                      float z_far);
 
 #ifndef COGL_DISABLE_DEPRECATED
 
@@ -238,8 +257,9 @@ void            _cogl_setup_viewport          (guint        width,
  *
  * Deprecated: 1.2: Use cogl_set_viewport() instead
  */
-void            cogl_viewport                 (guint               width,
-					       guint               height) G_GNUC_DEPRECATED;
+void
+cogl_viewport (unsigned int width,
+	       unsigned int height) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -254,10 +274,11 @@ void            cogl_viewport                 (guint               width,
  *
  * Since: 1.2
  */
-void            cogl_set_viewport             (int x,
-                                               int y,
-                                               int width,
-					       int height);
+void
+cogl_set_viewport (int x,
+                   int y,
+                   int width,
+                   int height);
 
 /**
  * cogl_push_matrix:
@@ -265,14 +286,16 @@ void            cogl_set_viewport             (int x,
  * Stores the current model-view matrix on the matrix stack. The matrix
  * can later be restored with cogl_pop_matrix().
  */
-void            cogl_push_matrix              (void);
+void
+cogl_push_matrix (void);
 
 /**
  * cogl_pop_matrix:
  *
  * Restores the current model-view matrix from the matrix stack.
  */
-void            cogl_pop_matrix               (void);
+void
+cogl_pop_matrix (void);
 
 /**
  * cogl_scale:
@@ -283,9 +306,10 @@ void            cogl_pop_matrix               (void);
  * Multiplies the current model-view matrix by one that scales the x,
  * y and z axes by the given values.
  */
-void            cogl_scale                    (float        x,
-                                               float        y,
-                                               float        z);
+void
+cogl_scale (float x,
+            float y,
+            float z);
 
 /**
  * cogl_translate:
@@ -296,9 +320,10 @@ void            cogl_scale                    (float        x,
  * Multiplies the current model-view matrix by one that translates the
  * model along all three axes according to the given values.
  */
-void            cogl_translate                (float                x,
-                                               float                y,
-                                               float                z);
+void
+cogl_translate (float x,
+                float y,
+                float z);
 
 /**
  * cogl_rotate:
@@ -313,10 +338,11 @@ void            cogl_translate                (float                x,
  * degrees about the vertex (0, 0, 1) causes a small counter-clockwise
  * rotation.
  */
-void            cogl_rotate                   (float                angle,
-                                               float                x,
-                                               float                y,
-                                               float                z);
+void
+cogl_rotate (float angle,
+             float x,
+             float y,
+             float z);
 
 /**
  * cogl_get_modelview_matrix:
@@ -324,7 +350,8 @@ void            cogl_rotate                   (float                angle,
  *
  * Stores the current model-view matrix in @matrix.
  */
-void            cogl_get_modelview_matrix     (CoglMatrix *matrix);
+void
+cogl_get_modelview_matrix (CoglMatrix *matrix);
 
 /**
  * cogl_set_modelview_matrix:
@@ -332,7 +359,8 @@ void            cogl_get_modelview_matrix     (CoglMatrix *matrix);
  *
  * Loads @matrix as the new model-view matrix.
  */
-void            cogl_set_modelview_matrix     (CoglMatrix *matrix);
+void
+cogl_set_modelview_matrix (CoglMatrix *matrix);
 
 /**
  * cogl_get_projection_matrix:
@@ -340,7 +368,8 @@ void            cogl_set_modelview_matrix     (CoglMatrix *matrix);
  *
  * Stores the current projection matrix in @matrix.
  */
-void            cogl_get_projection_matrix    (CoglMatrix *matrix);
+void
+cogl_get_projection_matrix (CoglMatrix *matrix);
 
 /**
  * cogl_set_projection_matrix:
@@ -348,7 +377,8 @@ void            cogl_get_projection_matrix    (CoglMatrix *matrix);
  *
  * Loads matrix as the new projection matrix.
  */
-void            cogl_set_projection_matrix    (CoglMatrix *matrix);
+void
+cogl_set_projection_matrix (CoglMatrix *matrix);
 
 /**
  * cogl_get_viewport:
@@ -359,7 +389,8 @@ void            cogl_set_projection_matrix    (CoglMatrix *matrix);
  * position of the viewport and @v[2] and @v[3] get the width and
  * height.
  */
-void            cogl_get_viewport             (float        v[4]);
+void
+cogl_get_viewport (float v[4]);
 
 /**
  * cogl_set_depth_test_enabled:
@@ -371,7 +402,8 @@ void            cogl_get_viewport             (float        v[4]);
  * clutter_actor_lower(), otherwise it will also take into account the
  * actor's depth. Depth testing is disabled by default.
  */
-void            cogl_set_depth_test_enabled   (gboolean setting);
+void
+cogl_set_depth_test_enabled (gboolean setting);
 
 /**
  * cogl_get_depth_test_enabled:
@@ -380,7 +412,8 @@ void            cogl_set_depth_test_enabled   (gboolean setting);
  *
  * Return value: %TRUE if depth testing is enabled, and %FALSE otherwise
  */
-gboolean        cogl_get_depth_test_enabled   (void);
+gboolean
+cogl_get_depth_test_enabled (void);
 
 /**
  * cogl_set_backface_culling_enabled:
@@ -392,7 +425,8 @@ gboolean        cogl_get_depth_test_enabled   (void);
  * only affects calls to the cogl_rectangle* family of functions and
  * cogl_vertex_buffer_draw*. Backface culling is disabled by default.
  */
-void            cogl_set_backface_culling_enabled (gboolean setting);
+void
+cogl_set_backface_culling_enabled (gboolean setting);
 
 /**
  * cogl_get_backface_culling_enabled:
@@ -402,7 +436,8 @@ void            cogl_set_backface_culling_enabled (gboolean setting);
  *
  * Return value: %TRUE if backface culling is enabled, and %FALSE otherwise
  */
-gboolean        cogl_get_backface_culling_enabled (void);
+gboolean
+cogl_get_backface_culling_enabled (void);
 
 /**
  * cogl_set_fog:
@@ -429,11 +464,12 @@ gboolean        cogl_get_backface_culling_enabled (void);
  * opaque primitives. This might improve in the future when we can depend
  * on fragment shaders.</note>
  */
-void            cogl_set_fog                  (const CoglColor *fog_color,
-                                               CoglFogMode      mode,
-                                               float            density,
-                                               float            z_near,
-                                               float            z_far);
+void
+cogl_set_fog (const CoglColor *fog_color,
+              CoglFogMode mode,
+              float density,
+              float z_near,
+              float z_far);
 
 /**
  * cogl_disable_fog:
@@ -441,7 +477,8 @@ void            cogl_set_fog                  (const CoglColor *fog_color,
  * This function disables fogging, so primitives drawn afterwards will not be
  * blended with any previously set fog color.
  */
-void            cogl_disable_fog              (void);
+void
+cogl_disable_fog (void);
 
 /**
  * CoglBufferBit:
@@ -468,8 +505,9 @@ typedef enum {
  * Clears all the auxiliary buffers identified in the @buffers mask, and if
  * that includes the color buffer then the specified @color is used.
  */
-void            cogl_clear                    (const CoglColor *color,
-                                               gulong           buffers);
+void
+cogl_clear (const CoglColor *color,
+            unsigned long buffers);
 
 /**
  * cogl_set_source:
@@ -484,7 +522,8 @@ void            cogl_clear                    (const CoglColor *color,
  *
  * Since: 1.0
  */
-void            cogl_set_source               (CoglHandle material);
+void
+cogl_set_source (CoglHandle material);
 
 /**
  * cogl_set_source_color:
@@ -503,7 +542,8 @@ void            cogl_set_source               (CoglHandle material);
  *
  * Since: 1.0
  */
-void            cogl_set_source_color         (const CoglColor *color);
+void
+cogl_set_source_color (const CoglColor *color);
 
 /**
  * cogl_set_source_color4ub:
@@ -521,10 +561,11 @@ void            cogl_set_source_color         (const CoglColor *color);
  *
  * Since: 1.0
  */
-void            cogl_set_source_color4ub      (guint8 red,
-                                               guint8 green,
-                                               guint8 blue,
-                                               guint8 alpha);
+void
+cogl_set_source_color4ub (guint8 red,
+                          guint8 green,
+                          guint8 blue,
+                          guint8 alpha);
 
 /**
  * cogl_set_source_color4f:
@@ -543,10 +584,11 @@ void            cogl_set_source_color4ub      (guint8 red,
  *
  * Since: 1.0
  */
-void            cogl_set_source_color4f       (float red,
-                                               float green,
-                                               float blue,
-                                               float alpha);
+void
+cogl_set_source_color4f (float red,
+                         float green,
+                         float blue,
+                         float alpha);
 
 /**
  * cogl_set_source_texture:
@@ -568,7 +610,8 @@ void            cogl_set_source_color4f       (float red,
  *
  * Since: 1.0
  */
-void            cogl_set_source_texture       (CoglHandle texture_handle);
+void
+cogl_set_source_texture (CoglHandle texture_handle);
 
 /**
  * SECTION:cogl-clipping
@@ -599,10 +642,11 @@ void            cogl_set_source_texture       (CoglHandle texture_handle);
  *
  * Deprecated: 1.2: Use cogl_clip_push_window_rectangle() instead
  */
-void            cogl_clip_push_window_rect    (float x_offset,
-                                               float y_offset,
-                                               float width,
-                                               float height) G_GNUC_DEPRECATED;
+void
+cogl_clip_push_window_rect (float x_offset,
+                            float y_offset,
+                            float width,
+                            float height) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -624,10 +668,11 @@ void            cogl_clip_push_window_rect    (float x_offset,
  *
  * Since: 1.2
  */
-void            cogl_clip_push_window_rectangle (int x_offset,
-                                                 int y_offset,
-                                                 int width,
-                                                 int height);
+void
+cogl_clip_push_window_rectangle (int x_offset,
+                                 int y_offset,
+                                 int width,
+                                 int height);
 
 #ifndef COGL_DISABLE_DEPRECATED
 
@@ -653,10 +698,11 @@ void            cogl_clip_push_window_rectangle (int x_offset,
  *   extending up, it's awkward to use. Please use cogl_clip_push_rectangle()
  *   instead
  */
-void            cogl_clip_push                (float        x_offset,
-                                               float        y_offset,
-                                               float        width,
-                                               float        height) G_GNUC_DEPRECATED;
+void
+cogl_clip_push (float x_offset,
+                float y_offset,
+                float width,
+                float height) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -678,10 +724,11 @@ void            cogl_clip_push                (float        x_offset,
  *
  * Since: 1.2
  */
-void            cogl_clip_push_rectangle      (float        x0,
-                                               float        y0,
-                                               float        x1,
-                                               float        y1);
+void
+cogl_clip_push_rectangle (float x0,
+                          float y0,
+                          float x1,
+                          float y1);
 
 /**
  * cogl_clip_push_from_path:
@@ -693,7 +740,8 @@ void            cogl_clip_push_rectangle      (float        x0,
  *
  * Since: 1.0
  */
-void            cogl_clip_push_from_path       (void);
+void
+cogl_clip_push_from_path (void);
 
 /**
  * cogl_clip_push_from_path_preserve:
@@ -705,7 +753,8 @@ void            cogl_clip_push_from_path       (void);
  *
  * Since: 1.0
  */
-void            cogl_clip_push_from_path_preserve (void);
+void
+cogl_clip_push_from_path_preserve (void);
 
 /**
  * cogl_clip_pop:
@@ -713,7 +762,8 @@ void            cogl_clip_push_from_path_preserve (void);
  * Reverts the clipping region to the state before the last call to
  * cogl_clip_push().
  */
-void            cogl_clip_pop               (void);
+void
+cogl_clip_pop (void);
 
 #ifndef COGL_DISABLE_DEPRECATED
 
@@ -729,7 +779,8 @@ void            cogl_clip_pop               (void);
  *
  * Since: 1.0
  */
-void            cogl_clip_ensure              (void) G_GNUC_DEPRECATED;
+void
+cogl_clip_ensure (void) G_GNUC_DEPRECATED;
 
 /**
  * cogl_clip_stack_save:
@@ -748,7 +799,8 @@ void            cogl_clip_ensure              (void) G_GNUC_DEPRECATED;
  *
  * Since: 0.8.2
  */
-void            cogl_clip_stack_save          (void) G_GNUC_DEPRECATED;
+void
+cogl_clip_stack_save (void) G_GNUC_DEPRECATED;
 
 /**
  * cogl_clip_stack_restore:
@@ -764,7 +816,8 @@ void            cogl_clip_stack_save          (void) G_GNUC_DEPRECATED;
  *
  * Since: 0.8.2
  */
-void            cogl_clip_stack_restore       (void) G_GNUC_DEPRECATED;
+void
+cogl_clip_stack_restore (void) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -780,7 +833,8 @@ void            cogl_clip_stack_restore       (void) G_GNUC_DEPRECATED;
  *
  * Since: 1.2
  */
-void            cogl_set_framebuffer          (CoglHandle buffer);
+void
+cogl_set_framebuffer (CoglHandle buffer);
 
 /**
  * cogl_push_framebuffer:
@@ -796,7 +850,8 @@ void            cogl_set_framebuffer          (CoglHandle buffer);
  *
  * Since: 1.2
  */
-void            cogl_push_framebuffer         (CoglHandle buffer);
+void
+cogl_push_framebuffer (CoglHandle buffer);
 
 /**
  * cogl_pop_framebuffer:
@@ -806,7 +861,8 @@ void            cogl_push_framebuffer         (CoglHandle buffer);
  *
  * Since: 1.2
  */
-void            cogl_pop_framebuffer          (void);
+void
+cogl_pop_framebuffer (void);
 
 #ifndef COGL_DISABLE_DEPRECATED
 
@@ -825,8 +881,9 @@ void            cogl_pop_framebuffer          (void);
  * Deprecated: 1.2: The target argument was redundant since we could look at
  *    the type of CoglHandle given instead.
  */
-void            cogl_set_draw_buffer          (CoglBufferTarget    target,
-                                               CoglHandle          offscreen) G_GNUC_DEPRECATED;
+void
+cogl_set_draw_buffer (CoglBufferTarget target,
+                      CoglHandle offscreen) G_GNUC_DEPRECATED;
 
 /**
  * cogl_push_draw_buffer:
@@ -835,7 +892,8 @@ void            cogl_set_draw_buffer          (CoglBufferTarget    target,
  *
  * Deprecated: 1.2: The draw buffer API was replaced with a framebuffer API
  */
-void            cogl_push_draw_buffer         (void) G_GNUC_DEPRECATED;
+void
+cogl_push_draw_buffer (void) G_GNUC_DEPRECATED;
 
 /**
  * cogl_pop_draw_buffer:
@@ -844,7 +902,8 @@ void            cogl_push_draw_buffer         (void) G_GNUC_DEPRECATED;
  *
  * Deprecated: 1.2: The draw buffer API was replaced with a framebuffer API
  */
-void            cogl_pop_draw_buffer          (void) G_GNUC_DEPRECATED;
+void
+cogl_pop_draw_buffer (void) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -876,13 +935,14 @@ typedef enum { /*< prefix=COGL_READ_PIXELS >*/
  * position (0, 0) is the top left. The pixel at (x, y) is the first
  * read, and the data is returned with a rowstride of (width * 4)
  */
-void            cogl_read_pixels (int x,
-                                  int y,
-                                  int width,
-                                  int height,
-                                  CoglReadPixelsFlags source,
-                                  CoglPixelFormat format,
-                                  guint8 *pixels);
+void
+cogl_read_pixels (int x,
+                  int y,
+                  int width,
+                  int height,
+                  CoglReadPixelsFlags source,
+                  CoglPixelFormat format,
+                  guint8 *pixels);
 
 /**
  * cogl_flush:
@@ -910,7 +970,8 @@ void            cogl_read_pixels (int x,
  *
  * Since: 1.0
  */
-void            cogl_flush (void);
+void
+cogl_flush (void);
 
 /**
  * cogl_begin_gl:
@@ -985,7 +1046,8 @@ void            cogl_flush (void);
  *
  * Since: 1.0
  */
-void            cogl_begin_gl (void);
+void
+cogl_begin_gl (void);
 
 /**
  * cogl_end_gl:
@@ -995,7 +1057,8 @@ void            cogl_begin_gl (void);
  *
  * Since: 1.0
  */
-void            cogl_end_gl (void);
+void
+cogl_end_gl (void);
 
 /*
  * Internal API available only to Clutter.
@@ -1006,7 +1069,8 @@ void            cogl_end_gl (void);
  * move down into Cogl and these functions will be removed.
  */
 
-void            _cogl_destroy_context          (void);
+void
+_cogl_destroy_context (void);
 
 /*< private >*/
 #define COGL_DRIVER_ERROR (_cogl_driver_error_quark ())
@@ -1016,10 +1080,20 @@ typedef enum { /*< prefix=COGL_DRIVER_ERROR >*/
   COGL_DRIVER_ERROR_INVALID_VERSION
 } CoglDriverError;
 
-void            _cogl_set_indirect_context  (gboolean indirect);
-void            _cogl_set_viewport (int x, int y, int width, int height);
-gboolean        _cogl_check_driver_valid (GError **error);
-GQuark          _cogl_driver_error_quark (void);
+gboolean
+_cogl_check_extension (const char *name, const char *ext);
+
+void
+_cogl_set_indirect_context  (gboolean indirect);
+
+void
+_cogl_set_viewport (int x, int y, int width, int height);
+
+gboolean
+_cogl_check_driver_valid (GError **error);
+
+GQuark
+_cogl_driver_error_quark (void);
 
 void
 _cogl_onscreen_clutter_backend_set_size (int width, int height);
