@@ -62,11 +62,15 @@ struct _ClutterBackendGLX
 {
   ClutterBackendX11 parent_instance;
 
+  int                    error_base;
+  int                    event_base;
+
   /* Single context for all wins */
   gboolean               found_fbconfig;
   GLXFBConfig            fbconfig;
   GLXContext             gl_context;
   Window                 dummy_xwin;
+  GLXWindow              dummy_glxwin;
 
   /* Vblank stuff */
   GetVideoSyncProc       get_video_sync;
