@@ -102,24 +102,20 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
 
   if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
     {
-      gint min_width, min_height;
-      ClutterGeometry min_size;
+      guint min_width, min_height;
       XSizeHints *size_hints;
 
       size_hints = XAllocSizeHints();
 
-      _clutter_stage_window_get_geometry (CLUTTER_STAGE_WINDOW (stage_x11),
-                                          &min_size);
+      clutter_stage_get_minimum_size (stage_x11->wrapper,
+                                      &min_width,
+                                      &min_height);
 
-      if (new_width < 0)
-        min_width = min_size.width;
-      else
-        min_width = new_width;
+      if (new_width <= 0)
+        new_width = min_width;
 
-      if (new_height < 0)
-        min_height = min_size.height;
-      else
-        min_height = new_height;
+      if (new_height <= 0)
+        new_height = min_height;
 
       size_hints->flags = 0;
 
@@ -127,15 +123,19 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
          restrictions on the window size */
       if (!stage_x11->fullscreen_on_map)
         {
-          size_hints->min_width = min_width;
-          size_hints->min_height = min_height;
-          size_hints->flags = PMinSize;
-
-          if (!resize)
+          if (resize)
             {
-              size_hints->max_width = size_hints->min_width;
-              size_hints->max_height = size_hints->min_height;
-              size_hints->flags |= PMaxSize;
+              size_hints->min_width = min_width;
+              size_hints->min_height = min_height;
+              size_hints->flags = PMinSize;
+            }
+          else
+            {
+              size_hints->min_width = new_width;
+              size_hints->min_height = new_height;
+              size_hints->max_width = new_width;
+              size_hints->max_height = new_height;
+              size_hints->flags = PMinSize | PMaxSize;
             }
         }
 
@@ -169,7 +169,7 @@ clutter_stage_x11_get_geometry (ClutterStageWindow *stage_window,
   ClutterBackend *backend = clutter_get_default_backend ();
   ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-  gboolean is_fullscreen, resize;
+  gboolean is_fullscreen;
 
   g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
@@ -187,19 +187,8 @@ clutter_stage_x11_get_geometry (ClutterStageWindow *stage_window,
       return;
     }
 
-  resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
-
-  if (resize)
-    {
-      /* FIXME need API to set this */
-      geometry->width = 1;
-      geometry->height = 1;
-    }
-  else
-    {
-      geometry->width = stage_x11->xwin_width;
-      geometry->height = stage_x11->xwin_height;
-    }
+  geometry->width = stage_x11->xwin_width;
+  geometry->height = stage_x11->xwin_height;
 }
 
 static void
@@ -230,27 +219,26 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
 
   CLUTTER_NOTE (BACKEND, "New size received: (%d, %d)", width, height);
 
-  if (width != stage_x11->xwin_width ||
-      height != stage_x11->xwin_height)
+  if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
     {
-      stage_x11->xwin_width  = width;
-      stage_x11->xwin_height = height;
+      clutter_stage_x11_fix_window_size (stage_x11, width, height);
 
-      if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
+      if (width != stage_x11->xwin_width ||
+          height != stage_x11->xwin_height)
         {
           CLUTTER_NOTE (BACKEND, "%s: XResizeWindow[%x] (%d, %d)",
                         G_STRLOC,
                         (unsigned int) stage_x11->xwin,
-                        stage_x11->xwin_width,
-                        stage_x11->xwin_height);
+                        width,
+                        height);
 
           CLUTTER_SET_PRIVATE_FLAGS (stage_x11->wrapper,
                                      CLUTTER_STAGE_IN_RESIZE);
 
           XResizeWindow (backend_x11->xdpy,
                          stage_x11->xwin,
-                         stage_x11->xwin_width,
-                         stage_x11->xwin_height);
+                         width,
+                         height);
 
           /* If the viewport hasn't previously been initialized then even
            * though we can't guarantee that the server will honour our request
@@ -260,17 +248,14 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
             {
               ClutterPerspective perspective;
               clutter_stage_get_perspective (stage, &perspective);
-              _cogl_setup_viewport (stage_x11->xwin_width,
-                                    stage_x11->xwin_height,
+              _cogl_setup_viewport (width,
+                                    height,
                                     perspective.fovy,
                                     perspective.aspect,
                                     perspective.z_near,
                                     perspective.z_far);
             }
         }
-
-      if (!resize)
-        clutter_stage_x11_fix_window_size (stage_x11, width, height);
     }
 }
 
@@ -281,7 +266,7 @@ set_wm_pid (ClutterStageX11 *stage_x11)
   ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
   long pid;
 
-  if (stage_x11->xwin == None)
+  if (stage_x11->xwin == None || stage_x11->is_foreign_xwin)
     return;
 
   /* this will take care of WM_CLIENT_MACHINE and WM_LOCALE_NAME */
@@ -291,7 +276,7 @@ set_wm_pid (ClutterStageX11 *stage_x11)
                     NULL, 0,
                     NULL, NULL, NULL);
 
-  pid = getpid();
+  pid = getpid ();
   XChangeProperty (backend_x11->xdpy,
                    stage_x11->xwin,
                    backend_x11->atom_NET_WM_PID, XA_CARDINAL, 32,
@@ -308,7 +293,7 @@ set_wm_title (ClutterStageX11 *stage_x11)
   g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  if (stage_x11->xwin == None)
+  if (stage_x11->xwin == None || stage_x11->is_foreign_xwin)
     return;
 
   if (stage_x11->title == NULL)
@@ -770,8 +755,10 @@ clutter_x11_get_stage_from_window (Window win)
  * along the lines of clutter_backend_x11_get_foreign_visual () or perhaps
  * clutter_stage_x11_get_foreign_visual ()
  *
- * Return value: An XVisualInfo suitable for creating a foreign stage.
- *               You should free this using XFree.
+ * Return value: An XVisualInfo suitable for creating a foreign stage. Use
+ *   XFree() to free the returned value instead
+ *
+ * Deprecated: 1.2: Use clutter_x11_get_visual_info() instead
  *
  * Since: 0.4
  */
